summaryrefslogtreecommitdiff
path: root/spec/fast_spec_helper.rb
diff options
context:
space:
mode:
Diffstat (limited to 'spec/fast_spec_helper.rb')
-rw-r--r--spec/fast_spec_helper.rb3
1 files changed, 2 insertions, 1 deletions
diff --git a/spec/fast_spec_helper.rb b/spec/fast_spec_helper.rb
index f28268b0754..978113a08a4 100644
--- a/spec/fast_spec_helper.rb
+++ b/spec/fast_spec_helper.rb
@@ -9,7 +9,8 @@ unless Object.respond_to?(:require_dependency)
end
end
-# Defines Gitlab and Gitlab.config which are at the center of the app
+# Defines Settings and Gitlab.config which are at the center of the app
+require_relative '../config/settings'
require_relative '../lib/gitlab' unless defined?(Gitlab.config)
require_relative 'support/rspec'